VSCoreInfo

Struct VSCoreInfo 

#[repr(C)]
pub struct VSCoreInfo { pub version_string: *const c_char, pub core: c_int, pub api: c_int, pub num_threads: c_int, pub max_framebuffer_size: i64, pub used_framebuffer_size: i64, }
Contains information about a VSCore instance.

Fields

version_string: *const c_char

Printable string containing the name of the library, copyright notice, core and API versions.

core: c_int

Version of the core.

api: c_int

Version of the API.

num_threads: c_int

Number of worker threads.

max_framebuffer_size: i64

The framebuffer cache will be allowed to grow up to this size (bytes) before memory is aggressively reclaimed.

used_framebuffer_size: i64

Current size of the framebuffer cache, in bytes.