#[repr(C)]pub struct VSCoreInfo2 {
pub version_string: *const c_char,
pub core: c_int,
pub api: c_int,
pub creation_flags: c_int,
pub num_threads: c_int,
pub max_framebuffer_size: i64,
pub used_framebuffer_size: i64,
}Expand description
Contains information about a VSCore instance.
Same as VSCoreInfo, plus the flags the core was created with. Added in API 4.2.
Fields
version_string: *const c_charPrintable string containing the name of the library, copyright notice, core and API versions.
core: c_intVersion of the core.
api: c_intVersion of the API.
creation_flags: c_intThe VSCoreCreationFlags the core was created with.
num_threads: c_intNumber of worker threads.
max_framebuffer_size: i64The framebuffer cache will be allowed to grow up to this size (bytes) before memory is aggressively reclaimed.
used_framebuffer_size: i64Current size of the framebuffer cache, in bytes.