pub struct VSPluginFunction { /* private fields */ }Expand description
A function belonging to a Vapoursynth plugin. This object primarily exists so a plugin’s name, argument list and return type can be queried by editors.
One peculiarity is that plugin functions cannot be invoked using a
VSPluginFunction pointer but is instead done using invoke()
which takes a VSPlugin and the function name as a string.